"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___GetTestRequest = GetTestRequest

@typing.final
class UpdateTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEST_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    TARGET_VERSION_FIELD_NUMBER: builtins.int
    IMBALANCE_POINT_FIELD_NUMBER: builtins.int
    IMBALANCE_TS_FIELD_NUMBER: builtins.int
    IMBALANCE_COMMENT_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    name: builtins.str
    description: builtins.str
    favorite: builtins.bool
    target_version: builtins.str
    imbalance_point: builtins.int
    imbalance_ts: builtins.int
    imbalance_comment: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        favorite: builtins.bool = ...,
        target_version: builtins.str = ...,
        imbalance_point: builtins.int = ...,
        imbalance_ts: builtins.int = ...,
        imbalance_comment: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "favorite", b"favorite", "imbalance_comment", b"imbalance_comment", "imbalance_point", b"imbalance_point", "imbalance_ts", b"imbalance_ts", "labels", b"labels", "name", b"name", "target_version", b"target_version", "test_id", b"test_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTestRequest = UpdateTestRequest

@typing.final
class UpdateTestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___UpdateTestMetadata = UpdateTestMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/node_execution_error_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/datasphere/v1/node_execution_error_details.proto\x12\x1ayandex.cloud.datasphere.v1\"Y\n\x19NodeExecutionErrorDetails\x12\x12\n\nerror_name\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x11\n\ttraceback\x18\x03 \x03(\tBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.node_execution_error_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_NODEEXECUTIONERRORDETAILS']._serialized_start=93
  _globals['_NODEEXECUTIONERRORDETAILS']._serialized_end=182
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1alpha/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.mysql.v1alpha.config import mysql5_7_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_config_dot_mysql5__7__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/mysql/v1alpha/cluster.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x34yandex/cloud/mdb/mysql/v1alpha/config/mysql5_7.proto\"\xd3\x06\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.mdb.mysql.v1alpha.Cluster.LabelsEntry\x12H\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.mysql.v1alpha.Cluster.Environment\x12>\n\nmonitoring\x18\x08 \x03(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.Monitoring\x12=\n\x06\x63onfig\x18\t \x01(\x0b\x32-.yandex.cloud.mdb.mysql.v1alpha.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12>\n\x06health\x18\x0b \x01(\x0e\x32..yandex.cloud.mdb.mysql.v1alpha.Cluster.Health\x12>\n\x06status\x18\x0c \x01(\x0e\x32..yandex.cloud.mdb.mysql.v1alpha.Cluster.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\x8a\x02\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x65\n\x10mysql_config_5_7\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mysql.v1alpha.config.MysqlConfigSet5_7H\x00R\x0fmysqlConfig_5_7\x12<\n\tresources\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.mysql.v1alpha.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x0e\n\x0cmysql_config\"\xc9\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12<\n\tresources\x18\x04 \x01(\x0b\x32).yandex.cloud.mdb.mysql.v1alpha.Resources\x12\x37\n\x04role\x18\x05 \x01(\x0e\x32).yandex.cloud.mdb.mysql.v1alpha.Host.Role\x12;\n\x06health\x18\x06 \x01(\x0e\x32+.yandex.cloud.mdb.mysql.v1alpha.Host.Health\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.yandex.cloud.mdb.mysql.v1alpha.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\x90\x02\n\x07Service\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.yandex.cloud.mdb.mysql.v1alpha.Service.Type\x12>\n\x06health\x18\x02 \x01(\x0e\x32..yandex.cloud.mdb.mysql.v1alpha.Service.Health\"V\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMYSQL_ERROR\x10\x01\x12\x11\n\rMYSQL_GENERAL\x10\x02\x12\x14\n\x10MYSQL_SLOW_QUERY\x10\x03\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\tBn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=197
  _globals['_CLUSTER']._serialized_end=1048
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=740
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=785
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=787
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=860
  _globals['_CLUSTER_HEALTH']._serialized_start=862
  _globals['_CLUSTER_HEALTH']._serialized_end=925
  _globals['_CLUSTER_STATUS']._serialized_start=927
  _globals['_CLUSTER_STATUS']._serialized_end=1048
  _globals['_MONITORING']._serialized_start=1050
  _globals['_MONITORING']._serialized_end=1111
  _globals['_CLUSTERCONFIG']._serialized_start=1114
  _globals['_CLUSTERCONFIG']._serialized_end=1380
  _globals['_HOST']._serialized_start=1383
  _globals['_HOST']._serialized_end=1840
  _globals['_HOST_ROLE']._serialized_start=1726
  _globals['_HOST_ROLE']._serialized_end=1775
  _globals['_HOST_HEALTH']._serialized_start=862
  _globals['_HOST_HEALTH']._serialized_end=925
  _globals['_SERVICE']._serialized_start=1843
  _globals['_SERVICE']._serialized_end=2115
  _globals['_SERVICE_TYPE']._serialized_start=1978
  _globals['_SERVICE_TYPE']._serialized_end=2064
  _globals['_SERVICE_HEALTH']._serialized_start=862
  _globals['_SERVICE_HEALTH']._serialized_end=911
  _globals['_RESOURCES']._serialized_start=2117
  _globals['_RESOURCES']._serialized_end=2197
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.ai.translate.v2.translation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TranslateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Format:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TranslateRequest._Format.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORMAT_UNSPECIFIED: TranslateRequest._Format.ValueType  # 0
        PLAIN_TEXT: TranslateRequest._Format.ValueType  # 1
        """Text without markup. Default value."""
        HTML: TranslateRequest._Format.ValueType  # 2
        """Text in the HTML format."""

    class Format(_Format, metaclass=_FormatEnumTypeWrapper): ...
    FORMAT_UNSPECIFIED: TranslateRequest.Format.ValueType  # 0
    PLAIN_TEXT: TranslateRequest.Format.ValueType  # 1
    """Text without markup. Default value."""
    HTML: TranslateRequest.Format.ValueType  # 2
    """Text in the HTML format."""

    SOURCE_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    TARGET_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TEXTS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    GLOSSARY_CONFIG_FIELD_NUMBER: builtins.int
    SPELLER_FIELD_NUMBER: builtins.int
    source_language_code: builtins.str
    """The text language to translate from.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` ru ``).

    Required for translating with glossary.
    """
    target_language_code: builtins.str
    """The target language to translate the text.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` en ``).
    """
    format: global___TranslateRequest.Format.ValueType
    """Format of the text."""
    folder_id: builtins.str
    """ID of the folder to which you have access.
    Required for authorization with a user account (see [yandex.cloud.iam.v1.UserAccount] resource).
    Don't specify this field if you make the request on behalf of a service account.
    """
    model: builtins.str
    """Do not specify this field, custom models are not supported yet."""
    speller: builtins.bool
    """use speller"""
    @property
    def texts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Array of the strings to translate.
        The maximum total length of all strings is 10000 characters.
        """

    @property
    def glossary_config(self) -> global___TranslateGlossaryConfig:
        """Glossary to be applied for the translation. For more information, see [Glossaries](/docs/translate/concepts/glossary)."""

    def __init__(
        self,
        *,
        source_language_code: builtins.str = ...,
        target_language_code: builtins.str = ...,
        format: global___TranslateRequest.Format.ValueType = ...,
        texts: collections.abc.Iterable[builtins.str] | None = ...,
        folder_id: builtins.str = ...,
        model: builtins.str = ...,
        glossary_config: global___TranslateGlossaryConfig | None = ...,
        speller: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["glossary_config", b"glossary_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "format", b"format", "glossary_config", b"glossary_config", "model", b"model", "source_language_code", b"source_language_code", "speller", b"speller", "target_language_code", b"target_language_code", "texts", b"texts"]) -> None: ...

global___TranslateRequest = TranslateRequest

@typing.final
class TranslateGlossaryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GLOSSARY_DATA_FIELD_NUMBER: builtins.int
    @property
    def glossary_data(self) -> global___GlossaryData:
        """Pass glossary data in the request. Currently, only this way to pass glossary is supported."""

    def __init__(
        self,
        *,
        glossary_data: global___GlossaryData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["glossary_data", b"glossary_data", "glossary_source", b"glossary_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["glossary_data", b"glossary_data", "glossary_source", b"glossary_source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["glossary_source", b"glossary_source"]) -> typing.Literal["glossary_data"] | None: ...

global___TranslateGlossaryConfig = TranslateGlossaryConfig

@typing.final
class GlossaryData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GLOSSARY_PAIRS_FIELD_NUMBER: builtins.int
    @property
    def glossary_pairs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GlossaryPair]:
        """Array of text pairs.

        The maximum total length of all source texts is 10000 characters.
        The maximum total length of all translated texts is 10000 characters.
        """

    def __init__(
        self,
        *,
        glossary_pairs: collections.abc.Iterable[global___GlossaryPair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["glossary_pairs", b"glossary_pairs"]) -> None: ...

global___GlossaryData = GlossaryData

@typing.final
class GlossaryPair(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TEXT_FIELD_NUMBER: builtins.int
    TRANSLATED_TEXT_FIELD_NUMBER: builtins.int
    EXACT_FIELD_NUMBER: builtins.int
    source_text: builtins.str
    """Text in the source language."""
    translated_text: builtins.str
    """Text in the target language."""
    exact: builtins.bool
    def __init__(
        self,
        *,
        source_text: builtins.str = ...,
        translated_text: builtins.str = ...,
        exact: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exact", b"exact", "source_text", b"source_text", "translated_text", b"translated_text"]) -> None: ...

global___GlossaryPair = GlossaryPair

@typing.final
class TranslateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSLATIONS_FIELD_NUMBER: builtins.int
    @property
    def translations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.translate.v2.translation_pb2.TranslatedText]:
        """Array of the translations."""

    def __init__(
        self,
        *,
        translations: collections.abc.Iterable[yandex.cloud.ai.translate.v2.translation_pb2.TranslatedText] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["translations", b"translations"]) -> None: ...

global___TranslateResponse = TranslateResponse

@typing.final
class DetectLanguageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_HINTS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    text: builtins.str
    """The text to detect the language for."""
    folder_id: builtins.str
    """ID of the folder to which you have access.
    Required for authorization with a user account (see [yandex.cloud.iam.v1.UserAccount] resource).
    Don't specify this field if you make the request on behalf of a service account.
    """
    @property
    def language_code_hints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of the most likely languages. These languages will be given preference when detecting the text language.
        Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` ru ``).

        To get the list of supported languages, use a [TranslationService.ListLanguages] request.
        """

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        language_code_hints: collections.abc.Iterable[builtins.str] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "language_code_hints", b"language_code_hints", "text", b"text"]) -> None: ...

global___DetectLanguageRequest = DetectLanguageRequest

@typing.final
class DetectLanguageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    language_code: builtins.str
    """The text language in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` ru ``).

    To get the language name, use a [TranslationService.ListLanguages] request.
    """
    def __init__(
        self,
        *,
        language_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language_code", b"language_code"]) -> None: ...

global___DetectLanguageResponse = DetectLanguageResponse

@typing.final
class ListLanguagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to which you have access.
    Required for authorization with a user account (see [yandex.cloud.iam.v1.UserAccount] resource).
    Don't specify this field if you make the request on behalf of a service account.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListLanguagesRequest = ListLanguagesRequest

@typing.final
class ListLanguagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.translate.v2.translation_pb2.Language]:
        """List of supported languages."""

    def __init__(
        self,
        *,
        languages: collections.abc.Iterable[yandex.cloud.ai.translate.v2.translation_pb2.Language] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["languages", b"languages"]) -> None: ...

global___ListLanguagesResponse = ListLanguagesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.video.v1.episode_pb2
import yandex.cloud.video.v1.manifest_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___GetEpisodeRequest = GetEpisodeRequest

@typing.final
class ListEpisodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    line_id: builtins.str
    """ID of the line."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Possible fields: ["id", "createdAt", "updatedAt"]
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    Value in quotes: `'` or `"`
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["title"]
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["line_id", b"line_id", "parent_id", b"parent_id", "stream_id", b"stream_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "line_id", b"line_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "parent_id", b"parent_id", "stream_id", b"stream_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["stream_id", "line_id"] | None: ...

global___ListEpisodesRequest = ListEpisodesRequest

@typing.final
class ListEpisodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.episode_pb2.Episode]:
        """List of episodes for specific parent_id."""

    def __init__(
        self,
        *,
        episodes: collections.abc.Iterable[yandex.cloud.video.v1.episode_pb2.Episode] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episodes", b"episodes", "next_page_token", b"next_page_token"]) -> None: ...

global___ListEpisodesResponse = ListEpisodesResponse

@typing.final
class BatchGetEpisodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    EPISODE_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def episode_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of requested episode IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        episode_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "episode_ids", b"episode_ids"]) -> None: ...

global___BatchGetEpisodesRequest = BatchGetEpisodesRequest

@typing.final
class BatchGetEpisodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODES_FIELD_NUMBER: builtins.int
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.episode_pb2.Episode]:
        """List of episodes for specific channel."""

    def __init__(
        self,
        *,
        episodes: collections.abc.Iterable[yandex.cloud.video.v1.episode_pb2.Episode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episodes", b"episodes"]) -> None: ...

global___BatchGetEpisodesResponse = BatchGetEpisodesResponse

@typing.final
class CreateEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    DVR_SECONDS_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    AUTH_SYSTEM_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Episode title."""
    description: builtins.str
    """Episode description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    dvr_seconds: builtins.int
    """Enables episode DVR mode. DVR seconds determines how many last seconds of the stream are available.

    possible values:
     * `0`: infinite dvr size, the full length of the stream allowed to display
     * `>0`: size of dvr window in seconds, the minimum value is 30s
    """
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode start time."""

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode finish time."""

    @property
    def public_access(self) -> global___EpisodePublicAccessParams:
        """Episode is available to everyone."""

    @property
    def auth_system_access(self) -> global___EpisodeAuthSystemAccessParams:
        """Checking access rights using the authorization system."""

    @property
    def sign_url_access(self) -> global___EpisodeSignURLAccessParams:
        """Checking access rights using url's signature."""

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dvr_seconds: builtins.int = ...,
        public_access: global___EpisodePublicAccessParams | None = ...,
        auth_system_access: global___EpisodeAuthSystemAccessParams | None = ...,
        sign_url_access: global___EpisodeSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "finish_time", b"finish_time", "line_id", b"line_id", "parent_id", b"parent_id", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "stream_id", b"stream_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "description", b"description", "dvr_seconds", b"dvr_seconds", "finish_time", b"finish_time", "line_id", b"line_id", "parent_id", b"parent_id", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "stream_id", b"stream_id", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "auth_system_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["stream_id", "line_id"] | None: ...

global___CreateEpisodeRequest = CreateEpisodeRequest

@typing.final
class EpisodePublicAccessParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodePublicAccessParams = EpisodePublicAccessParams

@typing.final
class EpisodeAuthSystemAccessParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodeAuthSystemAccessParams = EpisodeAuthSystemAccessParams

@typing.final
class EpisodeSignURLAccessParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodeSignURLAccessParams = EpisodeSignURLAccessParams

@typing.final
class CreateEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___CreateEpisodeMetadata = CreateEpisodeMetadata

@typing.final
class UpdateEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    DVR_SECONDS_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    AUTH_SYSTEM_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    title: builtins.str
    """Episode title."""
    description: builtins.str
    """Episode description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    dvr_seconds: builtins.int
    """Enables episode DVR mode. DVR seconds determines how many last seconds of the stream are available.

    possible values:
     * `0`: infinite dvr size, the full length of the stream allowed to display
     * `>0`: size of dvr window in seconds, the minimum value is 30s
    """
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the episode are going to be updated."""

    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode finish time."""

    @property
    def public_access(self) -> global___EpisodePublicAccessParams:
        """Episode is available to everyone."""

    @property
    def auth_system_access(self) -> global___EpisodeAuthSystemAccessParams:
        """Checking access rights using the authorization system."""

    @property
    def sign_url_access(self) -> global___EpisodeSignURLAccessParams:
        """Checking access rights using url's signature."""

    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dvr_seconds: builtins.int = ...,
        public_access: global___EpisodePublicAccessParams | None = ...,
        auth_system_access: global___EpisodeAuthSystemAccessParams | None = ...,
        sign_url_access: global___EpisodeSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "field_mask", b"field_mask", "finish_time", b"finish_time", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "description", b"description", "dvr_seconds", b"dvr_seconds", "episode_id", b"episode_id", "field_mask", b"field_mask", "finish_time", b"finish_time", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "auth_system_access", "sign_url_access"] | None: ...

global___UpdateEpisodeRequest = UpdateEpisodeRequest

@typing.final
class UpdateEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___UpdateEpisodeMetadata = UpdateEpisodeMetadata

@typing.final
class DeleteEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___DeleteEpisodeRequest = DeleteEpisodeRequest

@typing.final
class DeleteEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___DeleteEpisodeMetadata = DeleteEpisodeMetadata

@typing.final
class PerformEpisodeActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    UNPUBLISH_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    @property
    def publish(self) -> global___PublishEpisodeAction: ...
    @property
    def unpublish(self) -> global___UnpublishEpisodeAction: ...
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        publish: global___PublishEpisodeAction | None = ...,
        unpublish: global___UnpublishEpisodeAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "episode_id", b"episode_id", "publish", b"publish", "unpublish", b"unpublish"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "unpublish"] | None: ...

global___PerformEpisodeActionRequest = PerformEpisodeActionRequest

@typing.final
class PublishEpisodeAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishEpisodeAction = PublishEpisodeAction

@typing.final
class UnpublishEpisodeAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnpublishEpisodeAction = UnpublishEpisodeAction

@typing.final
class PerformEpisodeActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___PerformEpisodeActionMetadata = PerformEpisodeActionMetadata

@typing.final
class GetEpisodePlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    @property
    def params(self) -> global___EpisodePlayerParams: ...
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        params: global___EpisodePlayerParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id", "params", b"params"]) -> None: ...

global___GetEpisodePlayerURLRequest = GetEpisodePlayerURLRequest

@typing.final
class EpisodePlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, a player will be muted by default."""
    autoplay: builtins.bool
    """If true, playback will start automatically."""
    hidden: builtins.bool
    """If true, a player interface will be hidden by default."""
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___EpisodePlayerParams = EpisodePlayerParams

@typing.final
class GetEpisodePlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct link to the video."""
    html: builtins.str
    """HTML embed code in Iframe format."""
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetEpisodePlayerURLResponse = GetEpisodePlayerURLResponse

@typing.final
class GetEpisodeManifestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___GetEpisodeManifestsRequest = GetEpisodeManifestsRequest

@typing.final
class GetEpisodeManifestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTS_FIELD_NUMBER: builtins.int
    @property
    def manifests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.manifest_pb2.Manifest]: ...
    def __init__(
        self,
        *,
        manifests: collections.abc.Iterable[yandex.cloud.video.v1.manifest_pb2.Manifest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["manifests", b"manifests"]) -> None: ...

global___GetEpisodeManifestsResponse = GetEpisodeManifestsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/stream_line_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import stream_line_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__line__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/video/v1/stream_line_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/video/v1/stream_line.proto\"<\n\x14GetStreamLineRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xac\x01\n\x16ListStreamLinesRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x65 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"q\n\x17ListStreamLinesResponse\x12\x37\n\x0cstream_lines\x18\x01 \x03(\x0b\x32!.yandex.cloud.video.v1.StreamLine\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"i\n\x1a\x42\x61tchGetStreamLinesRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x0fstream_line_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04\x31-50\x8a\xc8\x31\x04<=50\"V\n\x1b\x42\x61tchGetStreamLinesResponse\x12\x37\n\x0cstream_lines\x18\x01 \x03(\x0b\x32!.yandex.cloud.video.v1.StreamLine\"\xe3\x06\n\x17\x43reateStreamLineRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05title\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0cthumbnail_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32:.yandex.cloud.video.v1.CreateStreamLineRequest.LabelsEntryB?\xf2\xc7\x31\x0f[-_.@:/0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12;\n\trtmp_push\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPushParamsH\x00\x12\x39\n\x08srt_push\x18\xe9\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPushParamsH\x00\x12;\n\trtmp_pull\x18\xea\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPullParamsH\x00\x12\x39\n\x08srt_pull\x18\xeb\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPullParamsH\x00\x12\x39\n\x08tcp_pull\x18\xec\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.TCPPullParamsH\x00\x12;\n\trtsp_pull\x18\xee\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTSPPullParamsH\x00\x12?\n\x0bmanual_line\x18\xd0\x0f \x01(\x0b\x32\'.yandex.cloud.video.v1.ManualLineParamsH\x01\x12;\n\tauto_line\x18\xd1\x0f \x01(\x0b\x32%.yandex.cloud.video.v1.AutoLineParamsH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x14\n\x0cinput_params\x12\x04\xc0\xc1\x31\x01\x42\x18\n\x10line_type_params\x12\x04\xc0\xc1\x31\x01J\x05\x08\x04\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xed\x07\x10\xee\x07J\x06\x08\xef\x07\x10\xd0\x0f\"2\n\x18\x43reateStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"\xeb\x05\n\x17UpdateStreamLineRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x1e\n\x0cthumbnail_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32:.yandex.cloud.video.v1.UpdateStreamLineRequest.LabelsEntryB?\xf2\xc7\x31\x0f[-_.@:/0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12;\n\trtmp_push\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPushParamsH\x00\x12\x39\n\x08srt_push\x18\xe9\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPushParamsH\x00\x12;\n\trtmp_pull\x18\xea\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTMPPullParamsH\x00\x12\x39\n\x08srt_pull\x18\xeb\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.SRTPullParamsH\x00\x12\x39\n\x08tcp_pull\x18\xec\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.TCPPullParamsH\x00\x12;\n\trtsp_pull\x18\xee\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.RTSPPullParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cinput_paramsJ\x05\x08\x05\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xed\x07\x10\xee\x07\"2\n\x18UpdateStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"?\n\x17\x44\x65leteStreamLineRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x18\x44\x65leteStreamLineMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"l\n\x1d\x42\x61tchDeleteStreamLinesRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x0fstream_line_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04\x31-50\x8a\xc8\x31\x04<=50\"9\n\x1e\x42\x61tchDeleteStreamLinesMetadata\x12\x17\n\x0fstream_line_ids\x18\x01 \x03(\t\"\xd3\x01\n\x18PerformLineActionRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x08\x61\x63tivate\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ActivateActionH\x00\x12>\n\ndeactivate\x18\xe9\x07 \x01(\x0b\x32\'.yandex.cloud.video.v1.DeactivateActionH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x05\x08\x02\x10\xe8\x07\"3\n\x19PerformLineActionMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t\"\x10\n\x0eRTMPPushParams\"\x0f\n\rSRTPushParams\"0\n\x0eRTMPPullParams\x12\x1e\n\x03url\x18\x01 \x01(\tB\x11\xe8\xc7\x31\x01\xf2\xc7\x31\trtmp://.*\".\n\rSRTPullParams\x12\x1d\n\x03url\x18\x01 \x01(\tB\x10\xe8\xc7\x31\x01\xf2\xc7\x31\x08srt://.*\"4\n\rTCPPullParams\x12\x1d\n\x03url\x18\x02 \x01(\tB\x10\xe8\xc7\x31\x01\xf2\xc7\x31\x08tcp://.*J\x04\x08\x01\x10\x02\"0\n\x0eRTSPPullParams\x12\x1e\n\x03url\x18\x01 \x01(\tB\x11\xe8\xc7\x31\x01\xf2\xc7\x31\trtsp://.*\"\x12\n\x10ManualLineParams\"\x10\n\x0e\x41utoLineParams\"\x10\n\x0e\x41\x63tivateAction\"\x12\n\x10\x44\x65\x61\x63tivateAction\";\n\x13GetStreamKeyRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\">\n\x16UpdateStreamKeyRequest\x12$\n\x0estream_line_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x17UpdateStreamKeyMetadata\x12\x16\n\x0estream_line_id\x18\x01 \x01(\t2\x82\x0e\n\x11StreamLineService\x12\x85\x01\n\x03Get\x12+.yandex.cloud.video.v1.GetStreamLineRequest\x1a!.yandex.cloud.video.v1.StreamLine\".\x82\xd3\xe4\x93\x02(\x12&/video/v1/streamLines/{stream_line_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.video.v1.ListStreamLinesRequest\x1a..yandex.cloud.video.v1.ListStreamLinesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/video/v1/streamLines\x12\x9c\x01\n\x08\x42\x61tchGet\x12\x31.yandex.cloud.video.v1.BatchGetStreamLinesRequest\x1a\x32.yandex.cloud.video.v1.BatchGetStreamLinesResponse\")\x82\xd3\xe4\x93\x02#\"\x1e/video/v1/streamLines:batchGet:\x01*\x12\xa7\x01\n\x06\x43reate\x12..yandex.cloud.video.v1.CreateStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*&\n\x18\x43reateStreamLineMetadata\x12\nStreamLine\x82\xd3\xe4\x93\x02\x1a\"\x15/video/v1/streamLines:\x01*\x12\xb8\x01\n\x06Update\x12..yandex.cloud.video.v1.UpdateStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*&\n\x18UpdateStreamLineMetadata\x12\nStreamLine\x82\xd3\xe4\x93\x02+2&/video/v1/streamLines/{stream_line_id}:\x01*\x12\xc0\x01\n\x06\x44\x65lete\x12..yandex.cloud.video.v1.DeleteStreamLineRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*1\n\x18\x44\x65leteStreamLineMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/video/v1/streamLines/{stream_line_id}\x12\xcf\x01\n\x0b\x42\x61tchDelete\x12\x34.yandex.cloud.video.v1.BatchDeleteStreamLinesRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*7\n\x1e\x42\x61tchDeleteStreamLinesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&\"!/video/v1/streamLines:batchDelete:\x01*\x12\xcf\x01\n\rPerformAction\x12/.yandex.cloud.video.v1.PerformLineActionRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*\'\n\x19PerformLineActionMetadata\x12\nStreamLine\x82\xd3\xe4\x93\x02\x39\"4/video/v1/streamLines/{stream_line_id}:performAction:\x01*\x12\x9d\x01\n\x0cGetStreamKey\x12*.yandex.cloud.video.v1.GetStreamKeyRequest\x1a$.yandex.cloud.video.v1.PushStreamKey\";\x82\xd3\xe4\x93\x02\x35\x12\x33/video/v1/streamLines/{stream_line_id}:getStreamKey\x12\xd2\x01\n\x0fUpdateStreamKey\x12-.yandex.cloud.video.v1.UpdateStreamKeyRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*(\n\x17UpdateStreamKeyMetadata\x12\rPushStreamKey\x82\xd3\xe4\x93\x02;26/video/v1/streamLines/{stream_line_id}:updateStreamKey:\x01*B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.stream_line_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _GETSTREAMLINEREQUEST.fields_by_name['stream_line_id']._options = None
  _GETSTREAMLINEREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSTREAMLINESREQUEST.fields_by_name['channel_id']._options = None
  _LISTSTREAMLINESREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSTREAMLINESREQUEST.fields_by_name['page_size']._options = None
  _LISTSTREAMLINESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSTREAMLINESREQUEST.fields_by_name['page_token']._options = None
  _LISTSTREAMLINESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _LISTSTREAMLINESREQUEST.fields_by_name['filter']._options = None
  _LISTSTREAMLINESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _BATCHGETSTREAMLINESREQUEST.fields_by_name['channel_id']._options = None
  _BATCHGETSTREAMLINESREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHGETSTREAMLINESREQUEST.fields_by_name['stream_line_ids']._options = None
  _BATCHGETSTREAMLINESREQUEST.fields_by_name['stream_line_ids']._serialized_options = b'\202\3101\0041-50\212\3101\004<=50'
  _CREATESTREAMLINEREQUEST_LABELSENTRY._options = None
  _CREATESTREAMLINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESTREAMLINEREQUEST.oneofs_by_name['input_params']._options = None
  _CREATESTREAMLINEREQUEST.oneofs_by_name['input_params']._serialized_options = b'\300\3011\001'
  _CREATESTREAMLINEREQUEST.oneofs_by_name['line_type_params']._options = None
  _CREATESTREAMLINEREQUEST.oneofs_by_name['line_type_params']._serialized_options = b'\300\3011\001'
  _CREATESTREAMLINEREQUEST.fields_by_name['channel_id']._options = None
  _CREATESTREAMLINEREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESTREAMLINEREQUEST.fields_by_name['title']._options = None
  _CREATESTREAMLINEREQUEST.fields_by_name['title']._serialized_options = b'\350\3071\001'
  _CREATESTREAMLINEREQUEST.fields_by_name['thumbnail_id']._options = None
  _CREATESTREAMLINEREQUEST.fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _CREATESTREAMLINEREQUEST.fields_by_name['labels']._options = None
  _CREATESTREAMLINEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_.@:/0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATESTREAMLINEREQUEST_LABELSENTRY._options = None
  _UPDATESTREAMLINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESTREAMLINEREQUEST.fields_by_name['stream_line_id']._options = None
  _UPDATESTREAMLINEREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESTREAMLINEREQUEST.fields_by_name['thumbnail_id']._options = None
  _UPDATESTREAMLINEREQUEST.fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATESTREAMLINEREQUEST.fields_by_name['labels']._options = None
  _UPDATESTREAMLINEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_.@:/0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _DELETESTREAMLINEREQUEST.fields_by_name['stream_line_id']._options = None
  _DELETESTREAMLINEREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETESTREAMLINESREQUEST.fields_by_name['channel_id']._options = None
  _BATCHDELETESTREAMLINESREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETESTREAMLINESREQUEST.fields_by_name['stream_line_ids']._options = None
  _BATCHDELETESTREAMLINESREQUEST.fields_by_name['stream_line_ids']._serialized_options = b'\202\3101\0041-50\212\3101\004<=50'
  _PERFORMLINEACTIONREQUEST.oneofs_by_name['action']._options = None
  _PERFORMLINEACTIONREQUEST.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _PERFORMLINEACTIONREQUEST.fields_by_name['stream_line_id']._options = None
  _PERFORMLINEACTIONREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RTMPPULLPARAMS.fields_by_name['url']._options = None
  _RTMPPULLPARAMS.fields_by_name['url']._serialized_options = b'\350\3071\001\362\3071\trtmp://.*'
  _SRTPULLPARAMS.fields_by_name['url']._options = None
  _SRTPULLPARAMS.fields_by_name['url']._serialized_options = b'\350\3071\001\362\3071\010srt://.*'
  _TCPPULLPARAMS.fields_by_name['url']._options = None
  _TCPPULLPARAMS.fields_by_name['url']._serialized_options = b'\350\3071\001\362\3071\010tcp://.*'
  _RTSPPULLPARAMS.fields_by_name['url']._options = None
  _RTSPPULLPARAMS.fields_by_name['url']._serialized_options = b'\350\3071\001\362\3071\trtsp://.*'
  _GETSTREAMKEYREQUEST.fields_by_name['stream_line_id']._options = None
  _GETSTREAMKEYREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESTREAMKEYREQUEST.fields_by_name['stream_line_id']._options = None
  _UPDATESTREAMKEYREQUEST.fields_by_name['stream_line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STREAMLINESERVICE.methods_by_name['Get']._options = None
  _STREAMLINESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/video/v1/streamLines/{stream_line_id}'
  _STREAMLINESERVICE.methods_by_name['List']._options = None
  _STREAMLINESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/video/v1/streamLines'
  _STREAMLINESERVICE.methods_by_name['BatchGet']._options = None
  _STREAMLINESERVICE.methods_by_name['BatchGet']._serialized_options = b'\202\323\344\223\002#\"\036/video/v1/streamLines:batchGet:\001*'
  _STREAMLINESERVICE.methods_by_name['Create']._options = None
  _STREAMLINESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateStreamLineMetadata\022\nStreamLine\202\323\344\223\002\032\"\025/video/v1/streamLines:\001*'
  _STREAMLINESERVICE.methods_by_name['Update']._options = None
  _STREAMLINESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateStreamLineMetadata\022\nStreamLine\202\323\344\223\002+2&/video/v1/streamLines/{stream_line_id}:\001*'
  _STREAMLINESERVICE.methods_by_name['Delete']._options = None
  _STREAMLINESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteStreamLineMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/video/v1/streamLines/{stream_line_id}'
  _STREAMLINESERVICE.methods_by_name['BatchDelete']._options = None
  _STREAMLINESERVICE.methods_by_name['BatchDelete']._serialized_options = b'\262\322*7\n\036BatchDeleteStreamLinesMetadata\022\025google.protobuf.Empty\202\323\344\223\002&\"!/video/v1/streamLines:batchDelete:\001*'
  _STREAMLINESERVICE.methods_by_name['PerformAction']._options = None
  _STREAMLINESERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*\'\n\031PerformLineActionMetadata\022\nStreamLine\202\323\344\223\0029\"4/video/v1/streamLines/{stream_line_id}:performAction:\001*'
  _STREAMLINESERVICE.methods_by_name['GetStreamKey']._options = None
  _STREAMLINESERVICE.methods_by_name['GetStreamKey']._serialized_options = b'\202\323\344\223\0025\0223/video/v1/streamLines/{stream_line_id}:getStreamKey'
  _STREAMLINESERVICE.methods_by_name['UpdateStreamKey']._options = None
  _STREAMLINESERVICE.methods_by_name['UpdateStreamKey']._serialized_options = b'\262\322*(\n\027UpdateStreamKeyMetadata\022\rPushStreamKey\202\323\344\223\002;26/video/v1/streamLines/{stream_line_id}:updateStreamKey:\001*'
  _globals['_GETSTREAMLINEREQUEST']._serialized_start=284
  _globals['_GETSTREAMLINEREQUEST']._serialized_end=344
  _globals['_LISTSTREAMLINESREQUEST']._serialized_start=347
  _globals['_LISTSTREAMLINESREQUEST']._serialized_end=519
  _globals['_LISTSTREAMLINESRESPONSE']._serialized_start=521
  _globals['_LISTSTREAMLINESRESPONSE']._serialized_end=634
  _globals['_BATCHGETSTREAMLINESREQUEST']._serialized_start=636
  _globals['_BATCHGETSTREAMLINESREQUEST']._serialized_end=741
  _globals['_BATCHGETSTREAMLINESRESPONSE']._serialized_start=743
  _globals['_BATCHGETSTREAMLINESRESPONSE']._serialized_end=829
  _globals['_CREATESTREAMLINEREQUEST']._serialized_start=832
  _globals['_CREATESTREAMLINEREQUEST']._serialized_end=1699
  _globals['_CREATESTREAMLINEREQUEST_LABELSENTRY']._serialized_start=1575
  _globals['_CREATESTREAMLINEREQUEST_LABELSENTRY']._serialized_end=1620
  _globals['_CREATESTREAMLINEMETADATA']._serialized_start=1701
  _globals['_CREATESTREAMLINEMETADATA']._serialized_end=1751
  _globals['_UPDATESTREAMLINEREQUEST']._serialized_start=1754
  _globals['_UPDATESTREAMLINEREQUEST']._serialized_end=2501
  _globals['_UPDATESTREAMLINEREQUEST_LABELSENTRY']._serialized_start=1575
  _globals['_UPDATESTREAMLINEREQUEST_LABELSENTRY']._serialized_end=1620
  _globals['_UPDATESTREAMLINEMETADATA']._serialized_start=2503
  _globals['_UPDATESTREAMLINEMETADATA']._serialized_end=2553
  _globals['_DELETESTREAMLINEREQUEST']._serialized_start=2555
  _globals['_DELETESTREAMLINEREQUEST']._serialized_end=2618
  _globals['_DELETESTREAMLINEMETADATA']._serialized_start=2620
  _globals['_DELETESTREAMLINEMETADATA']._serialized_end=2670
  _globals['_BATCHDELETESTREAMLINESREQUEST']._serialized_start=2672
  _globals['_BATCHDELETESTREAMLINESREQUEST']._serialized_end=2780
  _globals['_BATCHDELETESTREAMLINESMETADATA']._serialized_start=2782
  _globals['_BATCHDELETESTREAMLINESMETADATA']._serialized_end=2839
  _globals['_PERFORMLINEACTIONREQUEST']._serialized_start=2842
  _globals['_PERFORMLINEACTIONREQUEST']._serialized_end=3053
  _globals['_PERFORMLINEACTIONMETADATA']._serialized_start=3055
  _globals['_PERFORMLINEACTIONMETADATA']._serialized_end=3106
  _globals['_RTMPPUSHPARAMS']._serialized_start=3108
  _globals['_RTMPPUSHPARAMS']._serialized_end=3124
  _globals['_SRTPUSHPARAMS']._serialized_start=3126
  _globals['_SRTPUSHPARAMS']._serialized_end=3141
  _globals['_RTMPPULLPARAMS']._serialized_start=3143
  _globals['_RTMPPULLPARAMS']._serialized_end=3191
  _globals['_SRTPULLPARAMS']._serialized_start=3193
  _globals['_SRTPULLPARAMS']._serialized_end=3239
  _globals['_TCPPULLPARAMS']._serialized_start=3241
  _globals['_TCPPULLPARAMS']._serialized_end=3293
  _globals['_RTSPPULLPARAMS']._serialized_start=3295
  _globals['_RTSPPULLPARAMS']._serialized_end=3343
  _globals['_MANUALLINEPARAMS']._serialized_start=3345
  _globals['_MANUALLINEPARAMS']._serialized_end=3363
  _globals['_AUTOLINEPARAMS']._serialized_start=3365
  _globals['_AUTOLINEPARAMS']._serialized_end=3381
  _globals['_ACTIVATEACTION']._serialized_start=3383
  _globals['_ACTIVATEACTION']._serialized_end=3399
  _globals['_DEACTIVATEACTION']._serialized_start=3401
  _globals['_DEACTIVATEACTION']._serialized_end=3419
  _globals['_GETSTREAMKEYREQUEST']._serialized_start=3421
  _globals['_GETSTREAMKEYREQUEST']._serialized_end=3480
  _globals['_UPDATESTREAMKEYREQUEST']._serialized_start=3482
  _globals['_UPDATESTREAMKEYREQUEST']._serialized_end=3544
  _globals['_UPDATESTREAMKEYMETADATA']._serialized_start=3546
  _globals['_UPDATESTREAMKEYMETADATA']._serialized_end=3595
  _globals['_STREAMLINESERVICE']._serialized_start=3598
  _globals['_STREAMLINESERVICE']._serialized_end=5392
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2
import yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SpeakerStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_TAG_FIELD_NUMBER: builtins.int
    COMPLETE_STATISTICS_FIELD_NUMBER: builtins.int
    WORDS_PER_UTTERANCE_FIELD_NUMBER: builtins.int
    LETTERS_PER_UTTERANCE_FIELD_NUMBER: builtins.int
    UTTERANCE_COUNT_FIELD_NUMBER: builtins.int
    UTTERANCE_DURATION_ESTIMATION_FIELD_NUMBER: builtins.int
    speaker_tag: builtins.str
    """Speaker tag"""
    utterance_count: builtins.int
    """Number of utterances"""
    @property
    def complete_statistics(self) -> yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2.UtteranceStatistics:
        """analysis of all phrases in format of single utterance"""

    @property
    def words_per_utterance(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for words per utterance distribution"""

    @property
    def letters_per_utterance(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for letters per utterance distribution"""

    @property
    def utterance_duration_estimation(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for utterance duration distribution"""

    def __init__(
        self,
        *,
        speaker_tag: builtins.str = ...,
        complete_statistics: yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2.UtteranceStatistics | None = ...,
        words_per_utterance: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
        letters_per_utterance: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
        utterance_count: builtins.int = ...,
        utterance_duration_estimation: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["complete_statistics", b"complete_statistics", "letters_per_utterance", b"letters_per_utterance", "utterance_duration_estimation", b"utterance_duration_estimation", "words_per_utterance", b"words_per_utterance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["complete_statistics", b"complete_statistics", "letters_per_utterance", b"letters_per_utterance", "speaker_tag", b"speaker_tag", "utterance_count", b"utterance_count", "utterance_duration_estimation", b"utterance_duration_estimation", "words_per_utterance", b"words_per_utterance"]) -> None: ...

global___SpeakerStatistics = SpeakerStatistics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cloudregistry.v1.artifact_pb2
import yandex.cloud.cloudregistry.v1.artifact_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ArtifactServiceStub:
    """A set of methods for managing Artifacts."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudregistry.v1.artifact_service_pb2.GetArtifactRequest,
        yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact,
    ]
    """Returns the specified artifact resource.

    To get the list of available artifact resources, make [RegistryService.ListArtifacts] method call.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudregistry.v1.artifact_service_pb2.DeleteArtifactRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified artifact."""

class ArtifactServiceAsyncStub:
    """A set of methods for managing Artifacts."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudregistry.v1.artifact_service_pb2.GetArtifactRequest,
        yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact,
    ]
    """Returns the specified artifact resource.

    To get the list of available artifact resources, make [RegistryService.ListArtifacts] method call.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudregistry.v1.artifact_service_pb2.DeleteArtifactRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified artifact."""

class ArtifactServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Artifacts."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cloudregistry.v1.artifact_service_pb2.GetArtifactRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact, collections.abc.Awaitable[yandex.cloud.cloudregistry.v1.artifact_pb2.Artifact]]:
        """Returns the specified artifact resource.

        To get the list of available artifact resources, make [RegistryService.ListArtifacts] method call.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cloudregistry.v1.artifact_service_pb2.DeleteArtifactRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified artifact."""

def add_ArtifactServiceServicer_to_server(servicer: ArtifactServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.kafka.v1.topic_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTopicRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster that the topic belongs to.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    topic_name: builtins.str
    """Name of the Kafka topic resource to return.

    To get the name of the topic, make a [TopicService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name"]) -> None: ...

global___GetTopicRequest = GetTopicRequest

@typing.final
class ListTopicsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to list topics in.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListTopicsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set [page_token] to the [ListTopicsResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTopicsRequest = ListTopicsRequest

@typing.final
class ListTopicsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPICS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListTopicsRequest.page_size], use the [next_page_token] as the value for the [ListTopicsRequest.page_token] parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.topic_pb2.Topic]:
        """List of Kafka topics."""

    def __init__(
        self,
        *,
        topics: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.topic_pb2.Topic] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "topics", b"topics"]) -> None: ...

global___ListTopicsResponse = ListTopicsResponse

@typing.final
class CreateTopicRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to create a topic in.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    @property
    def topic_spec(self) -> yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec:
        """Configuration of the topic to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_spec: yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["topic_spec", b"topic_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_spec", b"topic_spec"]) -> None: ...

global___CreateTopicRequest = CreateTopicRequest

@typing.final
class CreateTopicMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster where a topic is being created."""
    topic_name: builtins.str
    """Name of the Kafka topic that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name"]) -> None: ...

global___CreateTopicMetadata = CreateTopicMetadata

@typing.final
class UpdateTopicRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    TOPIC_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to update a topic in.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    topic_name: builtins.str
    """Name of the topic to update.

    To get the name of the topic, make a [TopicService.List] request.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def topic_spec(self) -> yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec:
        """New configuration of the topic.

        Use [update_mask] to prevent reverting all topic settings that are not listed in [topic_spec] to their default values.
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        topic_spec: yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["topic_spec", b"topic_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name", "topic_spec", b"topic_spec", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTopicRequest = UpdateTopicRequest

@typing.final
class UpdateTopicMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster where a topic is being updated."""
    topic_name: builtins.str
    """Name of the Kafka topic that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name"]) -> None: ...

global___UpdateTopicMetadata = UpdateTopicMetadata

@typing.final
class DeleteTopicRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to delete a topic in.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    topic_name: builtins.str
    """Name of the topic to delete.

    To get the name of the topic, make a [TopicService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name"]) -> None: ...

global___DeleteTopicRequest = DeleteTopicRequest

@typing.final
class DeleteTopicMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster where a topic is being deleted."""
    topic_name: builtins.str
    """Name of the Kafka topic that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "topic_name", b"topic_name"]) -> None: ...

global___DeleteTopicMetadata = DeleteTopicMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/dashboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.monitoring.v3 import dashboard_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_dashboard__pb2
from yandex.cloud.monitoring.v3 import parametrization_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2
from yandex.cloud.monitoring.v3 import widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/monitoring/v3/dashboard_service.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a*yandex/cloud/monitoring/v3/dashboard.proto\x1a\x30yandex/cloud/monitoring/v3/parametrization.proto\x1a\'yandex/cloud/monitoring/v3/widget.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\x13GetDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa7\x01\n\x15ListDashboardsRequest\x12!\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x13 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x14 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x15 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\x0b\n\tcontainerJ\x04\x08\x03\x10\x13\"l\n\x16ListDashboardsResponse\x12\x39\n\ndashboards\x18\x01 \x03(\x0b\x32%.yandex.cloud.monitoring.v3.Dashboard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa1\x04\n\x16\x43reateDashboardRequest\x12!\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50H\x00\x12\x32\n\x04name\x18\x13 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x14 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x93\x01\n\x06labels\x18\x15 \x03(\x0b\x32>.yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\r\n\x05title\x18\x16 \x01(\t\x12\x33\n\x07widgets\x18\x17 \x03(\x0b\x32\".yandex.cloud.monitoring.v3.Widget\x12\x44\n\x0fparametrization\x18\x18 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.Parametrization\x12\x12\n\nmanaged_by\x18\x1a \x01(\t\x12\x14\n\x0cmanaged_link\x18\x1b \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\tcontainerJ\x04\x08\x03\x10\x13J\x04\x08\x19\x10\x1a\"/\n\x17\x43reateDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\x9d\x04\n\x16UpdateDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x93\x01\n\x06labels\x18\x04 \x03(\x0b\x32>.yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\r\n\x05title\x18\x05 \x01(\t\x12\x33\n\x07widgets\x18\x06 \x03(\x0b\x32\".yandex.cloud.monitoring.v3.Widget\x12\x44\n\x0fparametrization\x18\x07 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.Parametrization\x12\x0c\n\x04\x65tag\x18\x08 \x01(\t\x12\x12\n\nmanaged_by\x18\x1a \x01(\t\x12\x14\n\x0cmanaged_link\x18\x1b \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\t\x10\x1a\"/\n\x17UpdateDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"J\n\x16\x44\x65leteDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"/\n\x17\x44\x65leteDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\x82\x01\n\x1eListDashboardOperationsRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"q\n\x1fListDashboardOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb7\x08\n\x10\x44\x61shboardService\x12\x8f\x01\n\x03Get\x12/.yandex.cloud.monitoring.v3.GetDashboardRequest\x1a%.yandex.cloud.monitoring.v3.Dashboard\"0\x82\xd3\xe4\x93\x02*\x12(/monitoring/v3/dashboards/{dashboard_id}\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.monitoring.v3.ListDashboardsRequest\x1a\x32.yandex.cloud.monitoring.v3.ListDashboardsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/monitoring/v3/dashboards\x12\xad\x01\n\x06\x43reate\x12\x32.yandex.cloud.monitoring.v3.CreateDashboardRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*$\n\x17\x43reateDashboardMetadata\x12\tDashboard\x82\xd3\xe4\x93\x02\x1e\"\x19/monitoring/v3/dashboards:\x01*\x12\xbc\x01\n\x06Update\x12\x32.yandex.cloud.monitoring.v3.UpdateDashboardRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*$\n\x17UpdateDashboardMetadata\x12\tDashboard\x82\xd3\xe4\x93\x02-2(/monitoring/v3/dashboards/{dashboard_id}:\x01*\x12\xc5\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.monitoring.v3.DeleteDashboardRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*0\n\x17\x44\x65leteDashboardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/monitoring/v3/dashboards/{dashboard_id}\x12\xc6\x01\n\x0eListOperations\x12:.yandex.cloud.monitoring.v3.ListDashboardOperationsRequest\x1a;.yandex.cloud.monitoring.v3.ListDashboardOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/monitoring/v3/dashboards/{dashboard_id}/operationsBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.dashboard_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _GETDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _GETDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDASHBOARDSREQUEST.fields_by_name['folder_id']._options = None
  _LISTDASHBOARDSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDASHBOARDSREQUEST.fields_by_name['page_size']._options = None
  _LISTDASHBOARDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTDASHBOARDSREQUEST.fields_by_name['page_token']._options = None
  _LISTDASHBOARDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTDASHBOARDSREQUEST.fields_by_name['filter']._options = None
  _LISTDASHBOARDSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEDASHBOARDREQUEST_LABELSENTRY._options = None
  _CREATEDASHBOARDREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEDASHBOARDREQUEST.fields_by_name['folder_id']._options = None
  _CREATEDASHBOARDREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEDASHBOARDREQUEST.fields_by_name['name']._options = None
  _CREATEDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEDASHBOARDREQUEST.fields_by_name['description']._options = None
  _CREATEDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEDASHBOARDREQUEST.fields_by_name['labels']._options = None
  _CREATEDASHBOARDREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEDASHBOARDREQUEST_LABELSENTRY._options = None
  _UPDATEDASHBOARDREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _UPDATEDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEDASHBOARDREQUEST.fields_by_name['name']._options = None
  _UPDATEDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEDASHBOARDREQUEST.fields_by_name['description']._options = None
  _UPDATEDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEDASHBOARDREQUEST.fields_by_name['labels']._options = None
  _UPDATEDASHBOARDREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _DELETEDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['dashboard_id']._options = None
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DASHBOARDSERVICE.methods_by_name['Get']._options = None
  _DASHBOARDSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/monitoring/v3/dashboards/{dashboard_id}'
  _DASHBOARDSERVICE.methods_by_name['List']._options = None
  _DASHBOARDSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/monitoring/v3/dashboards'
  _DASHBOARDSERVICE.methods_by_name['Create']._options = None
  _DASHBOARDSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateDashboardMetadata\022\tDashboard\202\323\344\223\002\036\"\031/monitoring/v3/dashboards:\001*'
  _DASHBOARDSERVICE.methods_by_name['Update']._options = None
  _DASHBOARDSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateDashboardMetadata\022\tDashboard\202\323\344\223\002-2(/monitoring/v3/dashboards/{dashboard_id}:\001*'
  _DASHBOARDSERVICE.methods_by_name['Delete']._options = None
  _DASHBOARDSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteDashboardMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/monitoring/v3/dashboards/{dashboard_id}'
  _DASHBOARDSERVICE.methods_by_name['ListOperations']._options = None
  _DASHBOARDSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/monitoring/v3/dashboards/{dashboard_id}/operations'
  _globals['_GETDASHBOARDREQUEST']._serialized_start=352
  _globals['_GETDASHBOARDREQUEST']._serialized_end=409
  _globals['_LISTDASHBOARDSREQUEST']._serialized_start=412
  _globals['_LISTDASHBOARDSREQUEST']._serialized_end=579
  _globals['_LISTDASHBOARDSRESPONSE']._serialized_start=581
  _globals['_LISTDASHBOARDSRESPONSE']._serialized_end=689
  _globals['_CREATEDASHBOARDREQUEST']._serialized_start=692
  _globals['_CREATEDASHBOARDREQUEST']._serialized_end=1237
  _globals['_CREATEDASHBOARDREQUEST_LABELSENTRY']._serialized_start=1167
  _globals['_CREATEDASHBOARDREQUEST_LABELSENTRY']._serialized_end=1212
  _globals['_CREATEDASHBOARDMETADATA']._serialized_start=1239
  _globals['_CREATEDASHBOARDMETADATA']._serialized_end=1286
  _globals['_UPDATEDASHBOARDREQUEST']._serialized_start=1289
  _globals['_UPDATEDASHBOARDREQUEST']._serialized_end=1830
  _globals['_UPDATEDASHBOARDREQUEST_LABELSENTRY']._serialized_start=1167
  _globals['_UPDATEDASHBOARDREQUEST_LABELSENTRY']._serialized_end=1212
  _globals['_UPDATEDASHBOARDMETADATA']._serialized_start=1832
  _globals['_UPDATEDASHBOARDMETADATA']._serialized_end=1879
  _globals['_DELETEDASHBOARDREQUEST']._serialized_start=1881
  _globals['_DELETEDASHBOARDREQUEST']._serialized_end=1955
  _globals['_DELETEDASHBOARDMETADATA']._serialized_start=1957
  _globals['_DELETEDASHBOARDMETADATA']._serialized_end=2004
  _globals['_LISTDASHBOARDOPERATIONSREQUEST']._serialized_start=2007
  _globals['_LISTDASHBOARDOPERATIONSREQUEST']._serialized_end=2137
  _globals['_LISTDASHBOARDOPERATIONSRESPONSE']._serialized_start=2139
  _globals['_LISTDASHBOARDOPERATIONSRESPONSE']._serialized_end=2252
  _globals['_DASHBOARDSERVICE']._serialized_start=2255
  _globals['_DASHBOARDSERVICE']._serialized_end=3334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_ingestion_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/logging/v1/log_ingestion_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x17google/rpc/status.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a\x1dyandex/cloud/validation.proto\"\x90\x02\n\x0cWriteRequest\x12?\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32$.yandex.cloud.logging.v1.DestinationB\x04\xe8\xc7\x31\x01\x12;\n\x08resource\x18\x02 \x01(\x0b\x32).yandex.cloud.logging.v1.LogEntryResource\x12\x45\n\x07\x65ntries\x18\x03 \x03(\x0b\x32).yandex.cloud.logging.v1.IncomingLogEntryB\t\x82\xc8\x31\x05\x31-100\x12;\n\x08\x64\x65\x66\x61ults\x18\x04 \x01(\x0b\x32).yandex.cloud.logging.v1.LogEntryDefaults\"\x96\x01\n\rWriteResponse\x12\x42\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.logging.v1.WriteResponse.ErrorsEntry\x1a\x41\n\x0b\x45rrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status:\x02\x38\x01\x32m\n\x13LogIngestionService\x12V\n\x05Write\x12%.yandex.cloud.logging.v1.WriteRequest\x1a&.yandex.cloud.logging.v1.WriteResponseBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_ingestion_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _WRITEREQUEST.fields_by_name['destination']._options = None
  _WRITEREQUEST.fields_by_name['destination']._serialized_options = b'\350\3071\001'
  _WRITEREQUEST.fields_by_name['entries']._options = None
  _WRITEREQUEST.fields_by_name['entries']._serialized_options = b'\202\3101\0051-100'
  _WRITERESPONSE_ERRORSENTRY._options = None
  _WRITERESPONSE_ERRORSENTRY._serialized_options = b'8\001'
  _globals['_WRITEREQUEST']._serialized_start=222
  _globals['_WRITEREQUEST']._serialized_end=494
  _globals['_WRITERESPONSE']._serialized_start=497
  _globals['_WRITERESPONSE']._serialized_end=647
  _globals['_WRITERESPONSE_ERRORSENTRY']._serialized_start=582
  _globals['_WRITERESPONSE_ERRORSENTRY']._serialized_end=647
  _globals['_LOGINGESTIONSERVICE']._serialized_start=649
  _globals['_LOGINGESTIONSERVICE']._serialized_end=758
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.gateway_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the Gateway resource to return.

    To get Gateway resource ID make a [GatewayService.List] request.
    """
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___GetGatewayRequest = GetGatewayRequest

@typing.final
class ListGatewaysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list gateways in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListGatewaysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListGatewaysResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters Gateway listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Gateway.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-gateway`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGatewaysRequest = ListGatewaysRequest

@typing.final
class ListGatewaysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListGatewaysRequest.page_size], use `next_page_token` as the value
    for the [ListGatewaysRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.gateway_pb2.Gateway]:
        """List of gateways."""

    def __init__(
        self,
        *,
        gateways: collections.abc.Iterable[yandex.cloud.vpc.v1.gateway_pb2.Gateway] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateways", b"gateways", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGatewaysResponse = ListGatewaysResponse

@typing.final
class ListGatewayOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the gateway to list operations for.

    To get a gateway ID make a [GatewayService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListGatewayOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListGatewayOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGatewayOperationsRequest = ListGatewayOperationsRequest

@typing.final
class ListGatewayOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListGatewayOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListGatewayOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified gateway."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListGatewayOperationsResponse = ListGatewayOperationsResponse

@typing.final
class SharedEgressGatewaySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SharedEgressGatewaySpec = SharedEgressGatewaySpec

@typing.final
class CreateGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SHARED_EGRESS_GATEWAY_SPEC_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a gateway in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the gateway.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the gateway."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Gateway labels as `key:value` pairs."""

    @property
    def shared_egress_gateway_spec(self) -> global___SharedEgressGatewaySpec: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        shared_egress_gateway_spec: global___SharedEgressGatewaySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gateway", b"gateway", "shared_egress_gateway_spec", b"shared_egress_gateway_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "gateway", b"gateway", "labels", b"labels", "name", b"name", "shared_egress_gateway_spec", b"shared_egress_gateway_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["gateway", b"gateway"]) -> typing.Literal["shared_egress_gateway_spec"] | None: ...

global___CreateGatewayRequest = CreateGatewayRequest

@typing.final
class CreateGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the gateway that is being created."""
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___CreateGatewayMetadata = CreateGatewayMetadata

@typing.final
class UpdateGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SHARED_EGRESS_GATEWAY_SPEC_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the gateway to update.

    To get the gateway ID make a [GatewayService.List] request.
    """
    name: builtins.str
    """New name for the gateway.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the gateway."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the Gateway should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Gateway labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [GatewayService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def shared_egress_gateway_spec(self) -> global___SharedEgressGatewaySpec: ...
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        shared_egress_gateway_spec: global___SharedEgressGatewaySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gateway", b"gateway", "shared_egress_gateway_spec", b"shared_egress_gateway_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "gateway", b"gateway", "gateway_id", b"gateway_id", "labels", b"labels", "name", b"name", "shared_egress_gateway_spec", b"shared_egress_gateway_spec", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["gateway", b"gateway"]) -> typing.Literal["shared_egress_gateway_spec"] | None: ...

global___UpdateGatewayRequest = UpdateGatewayRequest

@typing.final
class UpdateGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the Gateway that is being updated."""
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___UpdateGatewayMetadata = UpdateGatewayMetadata

@typing.final
class DeleteGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the gateway to delete.

    To get a gateway ID make a [GatewayService.List] request.
    """
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___DeleteGatewayRequest = DeleteGatewayRequest

@typing.final
class DeleteGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """ID of the gateway that is being deleted."""
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___DeleteGatewayMetadata = DeleteGatewayMetadata

@typing.final
class MoveGatewayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    destination_folder_id: builtins.str
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "gateway_id", b"gateway_id"]) -> None: ...

global___MoveGatewayRequest = MoveGatewayRequest

@typing.final
class MoveGatewayMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id"]) -> None: ...

global___MoveGatewayMetadata = MoveGatewayMetadata
